This crate contains kube-rs compatible bindings for Kubernetes custom resources for the kmm.sigs.x-k8s.io group. Each binding is generated with kopium, updated and released weekly.
Available Custom Resources
kmm.sigs.x-k8s.io/v1beta1
ModuleNodeModulesConfigPreflightValidation
kmm.sigs.x-k8s.io/v1beta2
PreflightValidation